Widget class internals
~~~~~~~~~~~~~~~~~~~~~~

Several `.widgets.Widget` class internals have been privatized and deprecated:

* ``AxesWidget.cids``
* ``Button.cnt`` and ``Button.observers``
* ``CheckButtons.cnt`` and ``CheckButtons.observers``
* ``RadioButtons.cnt`` and ``RadioButtons.observers``
* ``Slider.cnt`` and ``Slider.observers``
* ``TextBox.cnt``, ``TextBox.change_observers`` and
  ``TextBox.submit_observers``
